variables

package
v3.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 1, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package variables provides access to Spin application variables.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Get

func Get(key string) (string, error)

Get returns an application variable value for the current component.

The name must match one defined in the component manifest.

Types

This section is empty.

Jump to